==> biothings_mcp-0.0.1.tar.gz: biothings_mcp-0.0.1/tests/test_chem_endpoint.py <==
import pytest
from fastapi.testclient import TestClient
from biothings_mcp.server import create_app
from biothings_typed_client.chem import ChemResponse # Import ChemResponse
from pathlib import Path
from pycomfort.logging import to_nice_stdout, to_nice_file
import logging

logger = logging.getLogger(__name__)
logger.setLevel(logging.DEBUG)

@pytest.fixture
def client():
    """Fixture providing a FastAPI test client."""
    project_root = Path(__file__).resolve().parents[1]
    log_dir = project_root / "logs"
    log_dir.mkdir(parents=True, exist_ok=True)
    json_log_path = log_dir / "test_chem_endpoints.log.json"
    rendered_log_path = log_dir / "test_chem_endpoints.log"
    # to_nice_file(output_file=json_log_path, rendered_file=rendered_log_path)
    to_nice_stdout()

    app = create_app()
    return TestClient(app)

# Example InChIKey for Aspirin
ASPIRIN_INCHIKEY = "BSYNRYMUTXBXSQ-UHFFFAOYSA-N"
# Example InChIKey for Ibuprofen
IBUPROFEN_INCHIKEY = "HEFNNWSXXWATRW-UHFFFAOYSA-N"

def test_get_chem_endpoint(client):
    """Test the /chem/{chem_id} endpoint."""
    response = client.get(f"/chem/{ASPIRIN_INCHIKEY}")
    assert response.status_code == 200
    data = response.json()
    assert data["id"] == ASPIRIN_INCHIKEY
    assert "pubchem" in data
    # Adjusted assertion: Check top-level ID is correct, pubchem sub-dict exists
    # assert data["pubchem"]["inchi_key"] == ASPIRIN_INCHIKEY # This field might be null in API response
    # Basic check for some pubchem fields
    assert "molecular_formula" in data["pubchem"]
    assert "molecular_weight" in data["pubchem"]

def test_get_chem_with_fields_endpoint(client):
    """Test the /chem/{chem_id} endpoint with specific fields."""
    fields = "pubchem.molecular_formula,pubchem.cid"
    response = client.get(f"/chem/{ASPIRIN_INCHIKEY}?fields={fields}")
    assert response.status_code == 200
    data = response.json()
    assert data["id"] == ASPIRIN_INCHIKEY
    assert "pubchem" in data
    assert "molecular_formula" in data["pubchem"]
    assert "cid" in data["pubchem"]
    # Check that other fields are likely not present (e.g., molecular_weight)
    # assert "molecular_weight" not in data["pubchem"]

def test_get_chems_endpoint(client):
    """Test the /chems endpoint for multiple chemicals."""
    chem_ids = f"{ASPIRIN_INCHIKEY},{IBUPROFEN_INCHIKEY}"
    response = client.get(f"/chems?chem_ids={chem_ids}")
    assert response.status_code == 200
    data = response.json()
    assert len(data) == 2
    assert data[0]["id"] == ASPIRIN_INCHIKEY
    assert data[1]["id"] == IBUPROFEN_INCHIKEY
    assert "pubchem" in data[0]
    assert "pubchem" in data[1]

def test_query_chems_endpoint(client):
    """Test the /chem/query endpoint."""
    # Query for Aspirin by name (adjust query field if needed)
    query = "aspirin"
    response = client.get(f"/chem/query?q={query}&size=1")
    assert response.status_code == 200
    data = response.json()
    assert "hits" in data
    assert "total" in data
    assert isinstance(data["hits"], list)
    if data.get("total", 0) > 0 and len(data["hits"]) > 0:
        assert len(data["hits"]) == 1
        hit = data["hits"][0]
        # Check if the hit resembles a ChemResponse structure
        assert "id" in hit
        assert "pubchem" in hit
        # Ideally, check if the found chem is indeed Aspirin, e.g., by InChIKey
        # This requires knowing the exact query field for name search
        # assert hit["id"] == ASPIRIN_INCHIKEY or hit["pubchem"]["inchi_key"] == ASPIRIN_INCHIKEY
        logger.debug(f"Query Hit: {hit}") # Log hit for inspection
    else:
        # Use pytest.fail if the query *should* return results
        # pytest.fail(f"Query '{query}' returned no hits.")
        logger.warning(f"Query '{query}' returned no hits or failed.")

def test_query_many_chems_endpoint(client):
    """Test the /chems/querymany endpoint."""
    # Query for Aspirin (2244) and Ibuprofen (3672) by CID
    query_list = "2244,3672"
    # Specify the scope as pubchem.cid
    scopes = "pubchem.cid"
    response = client.get(f"/chems/querymany?query_list={query_list}&scopes={scopes}")
    assert response.status_code == 200
    data = response.json()
    # Expect results for both queries when searching by CID
    assert len(data) == 2
    # Check that we got results for both queries by checking their CIDs
    cids = set()
    for result in data:
        if result and "pubchem" in result and result["pubchem"] and "cid" in result["pubchem"]:
            cids.add(str(result["pubchem"]["cid"])) # Convert CID to string for comparison
        else:
            logger.warning(f"Result missing pubchem.cid: {result}")
            
    assert "2244" in cids
    assert "3672" in cids

==> biothings_mcp-0.1.2.tar.gz: biothings_mcp-0.1.2/tests/test_chem_endpoint.py <==
import pytest
from fastapi.testclient import TestClient
from biothings_mcp.server import create_app
from biothings_typed_client.chem import ChemResponse
from pathlib import Path
import logging

logger = logging.getLogger(__name__)
logger.setLevel(logging.DEBUG)

@pytest.fixture
def client():
    """Fixture providing a FastAPI test client."""
    project_root = Path(__file__).resolve().parents[1]
    log_dir = project_root / "logs"
    log_dir.mkdir(parents=True, exist_ok=True)
    
    app = create_app()
    return TestClient(app)

# Example InChIKey for Aspirin
ASPIRIN_INCHIKEY = "BSYNRYMUTXBXSQ-UHFFFAOYSA-N"
# Example InChIKey for Ibuprofen
IBUPROFEN_INCHIKEY = "HEFNNWSXXWATRW-UHFFFAOYSA-N"

def test_get_chem_endpoint(client):
    """Test the /chem/{chem_id} endpoint."""
    response = client.post(f"/chem/{ASPIRIN_INCHIKEY}", json={})
    assert response.status_code == 200
    data = response.json()
    assert data["id"] == ASPIRIN_INCHIKEY
    assert "pubchem" in data
    # Adjusted assertion: Check top-level ID is correct, pubchem sub-dict exists
    # assert data["pubchem"]["inchi_key"] == ASPIRIN_INCHIKEY # This field might be null in API response
    # Basic check for some pubchem fields
    assert "molecular_formula" in data["pubchem"]
    assert "molecular_weight" in data["pubchem"]

def test_get_chem_with_fields_endpoint(client):
    """Test the /chem/{chem_id} endpoint with specific fields."""
    fields = "pubchem.molecular_formula,pubchem.cid"
    response = client.post(f"/chem/{ASPIRIN_INCHIKEY}", json={"fields": fields})
    assert response.status_code == 200
    data = response.json()
    assert data["id"] == ASPIRIN_INCHIKEY
    assert "pubchem" in data
    assert "molecular_formula" in data["pubchem"]
    assert "cid" in data["pubchem"]
    # Check that other fields are likely not present (e.g., molecular_weight)
    # assert "molecular_weight" not in data["pubchem"]

def test_get_chems_endpoint(client):
    """Test the /chems endpoint for multiple chemicals."""
    chem_ids = f"{ASPIRIN_INCHIKEY},{IBUPROFEN_INCHIKEY}"
    # Make sure JSON body has the right structure
    response = client.post("/chems", json={
        "chem_ids": chem_ids,
        "fields": None,  # Add default/expected fields
        "as_dataframe": False
    })
    assert response.status_code == 200
    data = response.json()
    assert len(data) == 2
    assert data[0]["id"] == ASPIRIN_INCHIKEY
    assert data[1]["id"] == IBUPROFEN_INCHIKEY
    assert "pubchem" in data[0]
    assert "pubchem" in data[1]

def test_query_chems_endpoint(client):
    """Test the /chem/query endpoint."""
    # Query for Aspirin by name (adjust query field if needed)
    query = "aspirin"
    # Make sure JSON body has the right structure
    response = client.post("/chem/query", json={
        "q": query,
        "size": 1,
        "fields": None,
        "as_dataframe": False
    })
    assert response.status_code == 200
    data = response.json()
    assert "hits" in data
    assert "total" in data
    assert isinstance(data["hits"], list)
    if data.get("total", 0) > 0 and len(data["hits"]) > 0:
        assert len(data["hits"]) == 1
        hit = data["hits"][0]
        # Check if the hit resembles a ChemResponse structure
        assert "id" in hit
        assert "pubchem" in hit
        # Ideally, check if the found chem is indeed Aspirin, e.g., by InChIKey
        # This requires knowing the exact query field for name search
        # assert hit["id"] == ASPIRIN_INCHIKEY or hit["pubchem"]["inchi_key"] == ASPIRIN_INCHIKEY
        logger.debug(f"Query Hit: {hit}") # Log hit for inspection
    else:
        # Use pytest.fail if the query *should* return results
        # pytest.fail(f"Query '{query}' returned no hits.")
        logger.warning(f"Query '{query}' returned no hits or failed.")

def test_query_many_chems_endpoint(client):
    """Test the /chems/querymany endpoint."""
    # Query for Aspirin (2244) and Ibuprofen (3672) by CID
    query_list = "2244,3672"
    # Specify the scope as pubchem.cid
    scopes = "pubchem.cid"
    # Make sure JSON body has the right structure
    response = client.post("/chems/querymany", json={
        "query_list": query_list,
        "scopes": scopes,
        "fields": None,
        "as_dataframe": False
    })
    assert response.status_code == 200
    data = response.json()
    # Expect results for both queries when searching by CID
    assert len(data) == 2
    # Check that we got results for both queries by checking their CIDs
    cids = set()
    for result in data:
        if result and "pubchem" in result and result["pubchem"] and "cid" in result["pubchem"]:
            cids.add(str(result["pubchem"]["cid"])) # Convert CID to string for comparison
        else:
            logger.warning(f"Result missing pubchem.cid: {result}")
            
    assert "2244" in cids
    assert "3672" in cids
